// area.js
'use strict';
// uses rest, reservation, tooltip

class areaEditClass extends reservationEdit{
	constructor(reservations, minimumUnit){
		super(reservations, minimumUnit);
		this.buttonMap = this.container.querySelector('button.map');
		this.svgObject = document.getElementById('svgobject');

		this.onButtonMap = this.onButtonMap.bind(this);
		this.onCloseButtonClick = this.onCloseButtonClick.bind(this);
		this.onAreaClick = this.onAreaClick.bind(this);


		this.buttonMap.addEventListener('click', this.onButtonMap);
		for(const area of document.querySelectorAll('.workspace map area')){
			area.addEventListener('click', this.onAreaClick);
		}
	}
	svgFindTagWithCData(svgDocument, tagName, cdataContent){
		const xpathExp = "//" + tagName + "[contains(text(), '" + cdataContent + "')]";
		const result = svgDocument.evaluate(xpathExp, svgDocument, null, XPathResult.ANY_TYPE, null);
		const foundElement = result.iterateNext();
		return foundElement;
	}

	redrawWorkspaceSelected(){
		// select-item から選択状態反映
		// getSelectItemIds();
		this.tableSelectUpdate();
		this.buttonDisableUpdate();
	}
	onButtonMap(){
		const workspace = document.querySelector('.workspace');
		workspace.style.display = 'block';
		this.redrawWorkspaceSelected();
	}
	onCloseButtonClick(event){
		workspace.style.display = 'none';
	}
	onAreaClick(event){
		const workspace = document.querySelector('.workspace');
		workspace.style.display = 'none';
		const itemId = event.target.dataset.itemId;
		for(const selectOption of this.selectItem){
			if(Number(selectOption.dataset.itemId) === Number(itemId)){
				this.selectItem.selectedIndex = selectOption.index;
				highlight(this.selectItem);
			}
		}
		this.redrawWorkspaceSelected();
	}
}

class areaReservationsClass extends reservations {
	// thead th
	updateTheadTh(theadDate, colGroupCol, theadTh){
		super.updateTheadTh(theadDate, colGroupCol, theadTh);
		theadTh.innerText = ((theadDate.getDate()===1) ? formatDate(theadDate, 'yyyy\nM/') : '') 
			+ formatDate(theadDate, 'd');
		theadTh.dataset.tooltip = formatDate((theadDate), 'yyyy/MM/dd');
		theadTh.addEventListener('click', areaTodayView.onTheadThClick);
	}
	// tbody th
	updateTbodyTh(atsItem, tbodyTh){
		super.updateTbodyTh(atsItem, tbodyTh);
		tbodyTh.dataset.tooltip = atsItems.findField('item_id', Number(tbodyTh.dataset.itemId)).item_desc;
		tbodyTh.addEventListener('click', areaEdit.onTbodyThClick);
	}
	// tbody td p
	updateTbodyData(reservationItem, tbodyP){
		super.updateTbodyData(reservationItem, tbodyP);
		tbodyP.dataset.tooltip = '';
		tbodyP.addEventListener('click', areaEdit.onTbodyDataClick);
	}
}

const areaReservations = new areaReservationsClass;
const areaTodayView = new todayView(areaReservations, MINIMUM_UNIT_DATE);
const areaEdit = new areaEditClass(areaReservations, MINIMUM_UNIT_DATE);

initializePage(areaReservations, areaEdit, BULK_RESERVATION);

