// toShare calendar.js
'use strict';
// uses rest, tooltip

const inputYear = document.querySelector('input.year');
const spanYearEnd = document.querySelector('span.year-end');
const buttonFix = document.querySelector('button.fix');
const divCalendar = document.querySelector('div.calendar');
const tableMonthTemplate = divCalendar.firstElementChild.cloneNode(true);
const trWeekTamplate = tableMonthTemplate.querySelector('tbody').firstElementChild.cloneNode(true);
tableMonthTemplate.querySelector('tbody').innerHTML = '';

async function updateCalendar(){
	const dateStart = inputYear.valueAsDate;
	dateStart.setHours(0,0,0);
	const dateEnd = new Date(dateStart);
	dateEnd.setFullYear(dateEnd.getFullYear() + 1);
	dateEnd.setDate(dateEnd.getDate() - 1);
	spanYearEnd.textContent = formatDate(dateEnd,'～ yyyy年 M月');
	await atsCalendar.restGet(dateStart, dateEnd);
	buttonFix.disabled = true;
	divCalendar.innerHTML = '';
	const dateCurrent = new Date(inputYear.value);
	const endMonth = dateCurrent.getMonth();
	let tableMonthCurrent;
	let trWeekCurrent;
	dateCurrent.setDate(1);
	do {
		if(dateCurrent.getDate() === 1){	// 月枠 追加
			tableMonthCurrent = tableMonthTemplate.cloneNode(true);
			const caption = tableMonthCurrent.createCaption();
			caption.textContent = formatDate(dateCurrent, 'yyyy年 M月');
			divCalendar.appendChild(tableMonthCurrent);
		}
		if((dateCurrent.getDate() === 1)
		|| (dateCurrent.getDay() === 0)){	// 週枠 追加
			trWeekCurrent = trWeekTamplate.cloneNode(true);
			tableMonthCurrent.appendChild(trWeekCurrent);
		}
		const pDay = document.createElement('p');	// 日 追加
		pDay.textContent = formatDate(dateCurrent, 'd');
		pDay.dataset.date = formatDate(dateCurrent, 'yyyy-MM-dd');
		const dateType = atsCalendar.dateType(new Date(pDay.dataset.date)); // lh sh
		if(dateType !== undefined){pDay.classList.add(dateType);}
		if(dateCurrent.getDay()!==0){	// 日曜以外
			pDay.addEventListener('click', onDayClick);
		}

		const tds = trWeekCurrent.querySelectorAll('td');
		tds[dateCurrent.getDay()].appendChild(pDay);

		// 翌日
		dateCurrent.setDate(dateCurrent.getDate() +1);
	} while ((dateCurrent.getMonth() !== endMonth) || (dateCurrent.getDate() !== 1));
}

function onDayClick(event){
	if(event.target.classList.contains('sh')){
		event.target.classList.remove('sh');
		// 平日sh削除
		const index = atsCalendar.data.findIndex(d => d['date'] === event.target.dataset.date);
		if(index !== -1){atsCalendar.data.splice(index, 1)}
		// 土曜null追加
		if(new Date(event.target.dataset.date).getDay() === 6){
			atsCalendar.data.push({
				date: event.target.dataset.date,
				type: null
			});
		};
	}else{
		event.target.classList.add('sh');
		// 平日sh追加
		if(new Date(event.target.dataset.date).getDay() !== 6){ 
			atsCalendar.data.push({
				date: event.target.dataset.date,
				type: 'sh'
			});
		}else{ // 土曜null削除
			const index = atsCalendar.data.findIndex(d => d['date'] === event.target.dataset.date);
			if(index !== -1){atsCalendar.data.splice(index, 1)}
		}
	}
	buttonFix.disabled = false;
}
async function onExecute(event){
	const dateStart = inputYear.valueAsDate;
	dateStart.setHours(0,0,0);
	const dateEnd = new Date(dateStart);
	dateEnd.setFullYear(dateEnd.getFullYear() + 1);
	dateEnd.setDate(dateEnd.getDate() - 1);
	try{
		await atsCalendar.restPut(dateStart, dateEnd, atsCalendar.data);
		confirm('更新しました。');
	}catch(e){confirm(e.message);}
	updateCalendar();
}

atsColorStyle.loadCss();
inputYear.value = formatDate((new Date), 'yyyy-01');
updateCalendar();
inputYear.addEventListener('change', updateCalendar);
buttonFix.addEventListener('click', onExecute);
